@@ -297,11 +297,12 @@ class TestBackwardCompatibility(BaseTestCase):
             }
         )
 
-        # Mock the auth service creation that the run function uses
+        # Mock the get_sheet_values function that the validator uses
         with patch(
-            "urarovite.auth.google_sheets.create_sheets_service_from_encoded_creds"
-        ) as mock_create_service:
-            mock_create_service.return_value = MagicMock()
+            "urarovite.validators.open_ended_ranges.get_sheet_values"
+        ) as mock_get_values:
+            # Mock sheet data for bounds - return some reasonable data
+            mock_get_values.return_value = {"success": True, "rows": 100, "cols": 5}
 
             result = run(row)
 
@@ -320,18 +321,14 @@ class TestBackwardCompatibility(BaseTestCase):
             }
         )
 
-        # Mock the auth service creation that the run function uses
+        # Mock the get_sheet_values function that the validator uses
         with patch(
-            "urarovite.auth.google_sheets.create_sheets_service_from_encoded_creds"
-        ) as mock_create_service:
-            with patch(
-                "urarovite.validators.open_ended_ranges.get_sheet_values"
-            ) as mock_get_values:
-                mock_create_service.return_value = MagicMock()
-                # Mock sheet data for bounds
-                mock_get_values.return_value = [["A1"], ["A2"], ["A3"]]
+            "urarovite.validators.open_ended_ranges.get_sheet_values"
+        ) as mock_get_values:
+            # Mock sheet data for bounds - return some reasonable data
+            mock_get_values.return_value = {"success": True, "rows": 100, "cols": 5}
 
-                result = run(row)
+            result = run(row)
 
         # Should have same structure as original checker4
         assert result["flags_found"] > 0
