@@ -39,6 +39,7 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
         """Test successful Google Sheets to Excel conversion."""
         with mock_manager.spreadsheet_scenario(
             source_sheets=["Sheet1", "Sheet2"],
+            target_sheets=["Sheet1", "Sheet2"],
             sheet_data={
                 "Sheet1": [["A1", "B1"], ["A2", "B2"]],
                 "Sheet2": [["C1", "D1"], ["C2", "D2"]],
@@ -62,6 +63,7 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
         """Test conversion of specific sheets only."""
         with mock_manager.spreadsheet_scenario(
             source_sheets=["Sheet1", "Sheet2", "Sheet3"],
+            target_sheets=["Sheet1", "Sheet3"],
             sheet_data={
                 "Sheet1": [["A1", "B1"]],
                 "Sheet2": [["C1", "D1"]],
@@ -84,7 +86,7 @@ class TestConvertGoogleSheetsToExcel(BaseTestCase):
     def test_conversion_with_errors(self):
         """Test conversion with some errors."""
         with mock_manager.spreadsheet_scenario(
-            source_sheets=["Sheet1", "Sheet2"]
+            source_sheets=["Sheet1", "Sheet2"], target_sheets=["Sheet1"]
         ) as mocks:
             # Make one sheet fail
             mocks["source"].get_sheet_data.side_effect = [
