@@ -1,7 +1,22 @@
-"""Tests for TabNameAlphanumericValidator.
+"""
+Tab Name Alphanumeric Validator.
 
-This validator ensures tab names contain only letters, numbers, and spaces.
-Special characters (including underscores) are omitted.
+This validator ensures that all tab names contain only alphanumeric characters
+(letters and numbers) and spaces. Non-alphanumeric characters (except spaces)
+are omitted, and consecutive spaces are collapsed to single spaces.
+Underscores are converted to spaces for better readability.
+
+Goal:
+Sanitize tab names to be alphanumeric with spaces for maximum compatibility
+across different systems while maintaining readability.
+
+Why:
+Tab names with special characters can cause issues in various contexts:
+- API integrations that expect clean identifiers
+- Export/import operations
+- Formula references
+- Database operations
+- Cross-platform compatibility
 """
 
 import unittest
@@ -18,6 +33,11 @@ try:
         TabNameAlphanumericValidator,
         sanitize_tab_names_to_alphanumeric,
     )
+    from urarovite.utils.tab_name_sanitizer import (
+        sanitize_tab_name,
+        detect_non_alphanumeric_tabs,
+        ensure_unique_names,
+    )
 except ImportError as e:
     print(f"Warning: Could not import validator modules: {e}")
     print("This may be due to missing dependencies. Trying direct import...")
@@ -107,8 +127,7 @@ class TestTabNameAlphanumericValidator(unittest.TestCase):
         self.assertEqual(self.validator.id, "tab_name_alphanumeric")
         self.assertEqual(self.validator.name, "Tab Name Alphanumeric")
         self.assertIn("letters, numbers, and spaces", self.validator.description)
-        self.assertIn("omits special characters", self.validator.description)
-        self.assertIn("underscores", self.validator.description)
+        self.assertIn("converts underscores to spaces", self.validator.description)
 
     def test_sanitize_tab_name_basic_cases(self):
         """Test basic sanitization functionality."""
@@ -118,7 +137,7 @@ class TestTabNameAlphanumericValidator(unittest.TestCase):
             ("Sheet 1", "Sheet 1"),  # Already valid with space
             ("Sheet1", "Sheet1"),  # Already valid alphanumeric
             # Remove special characters (including underscores)
-            ("Sheet_with_underscores", "Sheetwithunderscores"),
+            ("Sheet_with_underscores", "Sheet with underscores"),
             ("Sheet@#$%^&*()", "Sheet"),
             ("Data/Analysis", "DataAnalysis"),
             ("Report\\Final", "ReportFinal"),
@@ -144,25 +163,31 @@ class TestTabNameAlphanumericValidator(unittest.TestCase):
 
         for input_name, expected in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected)
 
     def test_sanitize_tab_name_space_handling(self):
         """Test space handling in sanitization."""
         test_cases = [
             # Multiple spaces collapsed to single space
-            ("Sheet    with    spaces", "Sheet with spaces"),
+            ("Sheet   with   spaces", "Sheet with spaces"),
             ("   Sheet   ", "Sheet"),  # Leading/trailing spaces removed
             ("Sheet  Multiple  Spaces", "Sheet Multiple Spaces"),
             # Mixed spaces and special characters
-            ("Sheet___with___underscores", "Sheetwithunderscores"),
+            (
+                "Sheet___with___underscores",
+                "Sheet with underscores",
+            ),  # Underscores converted to spaces, then collapsed
             ("Sheet   @   Special", "Sheet Special"),
-            ("Data___Analysis___Report", "DataAnalysisReport"),
+            (
+                "Data___Analysis___Report",
+                "Data Analysis Report",
+            ),  # Underscores converted to spaces
         ]
 
         for input_name, expected in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected)
 
     def test_sanitize_tab_name_edge_cases(self):
@@ -181,44 +206,44 @@ class TestTabNameAlphanumericValidator(unittest.TestCase):
             ("999", "Sheet 999"),
             ("42Analysis", "Sheet 42Analysis"),
             # Mixed cases
-            ("1_2_3", "Sheet 123"),
+            ("1_2_3", "Sheet 1 2 3"),
             ("___123___", "Sheet 123"),
         ]
 
         for input_name, expected in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected)
 
     def test_sanitize_tab_name_complex_cases(self):
         """Test complex sanitization scenarios."""
         test_cases = [
             # Real-world examples
-            ("Q1_2024_Sales_Report", "Q12024SalesReport"),
-            ("Data-Analysis_Final@Version", "DataAnalysisFinalVersion"),
+            ("Q1_2024_Sales_Report", "Q1 2024 Sales Report"),
+            ("Data-Analysis_Final@Version", "DataAnalysis FinalVersion"),
             ("Marketing/Campaign[Results]", "MarketingCampaignResults"),
-            ("Employee_Performance_Review_2024", "EmployeePerformanceReview2024"),
-            ("Sheet_#1_with_lots_of_stuff!", "Sheet1withlotsofstuff"),
-            ("___messy___name___with___underscores___", "messynamewithunderscores"),
+            ("Employee_Performance_Review_2024", "Employee Performance Review 2024"),
+            ("Sheet_#1_with_lots_of_stuff!", "Sheet 1 with lots of stuff"),
+            ("___messy___name___with___underscores___", "messy name with underscores"),
             # Unicode and special characters
             ("Sheet™©®", "Sheet"),
             (
                 "Données_Analysis",
-                "DonnesAnalysis",
-            ),  # Accented chars removed, underscores omitted
+                "Donnes Analysis",
+            ),  # Accented chars removed, underscores converted to spaces
             ("Sheet€$¥£", "Sheet"),
         ]
 
         for input_name, expected in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected)
 
     def test_detect_non_alphanumeric_tabs(self):
         """Test detection of tabs needing sanitization."""
         # Valid tabs (no changes needed)
         valid_tabs = ["Sheet1", "Data Analysis", "Report 2024", "Simple"]
-        result = self.validator._detect_non_alphanumeric_tabs(valid_tabs)
+        result = detect_non_alphanumeric_tabs(valid_tabs)
         self.assertEqual(result, {})
 
         # Invalid tabs (changes needed)
@@ -228,47 +253,42 @@ class TestTabNameAlphanumericValidator(unittest.TestCase):
             "Valid Sheet",  # This is valid
             "Report/Final",
         ]
-        result = self.validator._detect_non_alphanumeric_tabs(invalid_tabs)
+        result = detect_non_alphanumeric_tabs(invalid_tabs)
 
         expected = {
-            "Sheet_with_underscores": "Sheetwithunderscores",
+            "Sheet_with_underscores": "Sheet with underscores",
             "Data@#$%": "Data",
             "Report/Final": "ReportFinal",
         }
         self.assertEqual(result, expected)
 
     def test_ensure_unique_names(self):
-        """Test unique name generation when conflicts occur."""
-        all_tabs = ["Sheet1", "Data", "Data 2", "Report"]
+        """Test unique name generation."""
+        rename_mapping = {"Sheet1": "Sheet", "Sheet2": "Sheet"}
+        all_tabs = ["Sheet1", "Sheet2", "ExistingSheet"]
 
-        # No conflicts
-        rename_mapping = {"NewSheet": "NewSheet"}
-        result = self.validator._ensure_unique_names(rename_mapping, all_tabs)
-        self.assertEqual(result, {"NewSheet": "NewSheet"})
+        result = ensure_unique_names(rename_mapping, all_tabs)
 
-        # Conflict resolution
-        rename_mapping = {
-            "Old_Data": "Data",  # Conflicts with existing
-            "Sheet_1": "Sheet1",  # Conflicts with existing
-        }
-        result = self.validator._ensure_unique_names(rename_mapping, all_tabs)
+        # Should have unique names
+        self.assertEqual(result["Sheet1"], "Sheet")
+        self.assertEqual(result["Sheet2"], "Sheet 2")  # Gets suffix to avoid collision
 
-        # Should get unique names with numeric suffixes
-        self.assertEqual(result["Old_Data"], "Data 3")  # Data 2 already exists
-        self.assertEqual(result["Sheet_1"], "Sheet1 2")
+        # Test with no conflicts
+        rename_mapping = {"Sheet1": "NewSheet"}
+        result = ensure_unique_names(rename_mapping, all_tabs)
+        self.assertEqual(result["Sheet1"], "NewSheet")
 
     def test_ensure_unique_names_multiple_conflicts(self):
-        """Test unique name generation with multiple levels of conflicts."""
-        all_tabs = ["Report", "Report 2", "Report 3"]
+        """Test unique name generation with multiple conflicts."""
+        rename_mapping = {"Sheet1": "Data", "Sheet2": "Data", "Sheet3": "Data"}
+        all_tabs = ["Sheet1", "Sheet2", "Sheet3", "ExistingData"]
 
-        rename_mapping = {"Report_Old": "Report", "Report_New": "Report"}
-        result = self.validator._ensure_unique_names(rename_mapping, all_tabs)
+        result = ensure_unique_names(rename_mapping, all_tabs)
 
-        # Both should get unique sequential numbers
-        names = list(result.values())
-        self.assertEqual(len(set(names)), 2)  # Both should be unique
-        self.assertIn("Report 4", names)
-        self.assertIn("Report 5", names)
+        # All should get unique names
+        self.assertEqual(result["Sheet1"], "Data")
+        self.assertEqual(result["Sheet2"], "Data 2")
+        self.assertEqual(result["Sheet3"], "Data 3")
 
     def test_standalone_function(self):
         """Test the standalone sanitize_tab_names_to_alphanumeric function."""
@@ -447,13 +467,13 @@ class TestRegressionFromOldBehavior(unittest.TestCase):
         test_cases = [
             # Old behavior: replaced with underscores
             # New behavior: omits bad chars, supports spaces
-            ("My_Sheet@#$123", "MySheet123"),  # OLD: "My_Sheet_123"
-            ("Data___Analysis", "DataAnalysis"),  # OLD: "Data_Analysis"
+            ("My_Sheet@#$123", "My Sheet123"),  # OLD: "My_Sheet_123"
+            ("Data___Analysis", "Data Analysis"),  # OLD: "Data_Analysis"
             (
                 "Report/Final\\Version",
                 "ReportFinalVersion",
             ),  # OLD: "Report_Final_Version"
-            ("Sheet[1]_Test", "Sheet1Test"),  # OLD: "Sheet_1__Test"
+            ("Sheet[1]_Test", "Sheet1 Test"),  # OLD: "Sheet_1__Test"
             # Cases that should work the same
             ("SimpleSheet", "SimpleSheet"),
             ("Sheet123", "Sheet123"),
@@ -462,28 +482,21 @@ class TestRegressionFromOldBehavior(unittest.TestCase):
 
         for input_name, expected_new in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected_new)
 
-                # Ensure underscores are NOT in the result (key difference)
-                # unless they were in a valid input already
-                if "_" in input_name and input_name != "Already_Clean_Input":
-                    self.assertNotIn(
-                        "_", result, f"Result '{result}' should not contain underscores"
-                    )
-
     def test_spaces_are_preserved_and_normalized(self):
         """Test that spaces are preserved and normalized correctly."""
         test_cases = [
             ("Sheet with spaces", "Sheet with spaces"),  # Preserved
             ("Sheet   multiple   spaces", "Sheet multiple spaces"),  # Normalized
             ("  Trimmed  ", "Trimmed"),  # Trimmed
-            ("Sheet_to_spaces", "Sheettospaces"),  # Underscores omitted
+            ("Sheet_to_spaces", "Sheet to spaces"),  # Underscores converted to spaces
         ]
 
         for input_name, expected in test_cases:
             with self.subTest(input_name=input_name):
-                result = self.validator._sanitize_tab_name(input_name)
+                result = sanitize_tab_name(input_name)
                 self.assertEqual(result, expected)
 
 
