@@ -48,6 +48,9 @@ class TestValidationResultStandardization:
             "numeric_rounding",
             "unique_id_properties",
             "fixed_verification_ranges",
+            "format_compatibility",
+            "broken_values",
+            "verification_range_matching",
         }
 
         registered_validators = set(registry.keys())
