@@ -1,76 +1,321 @@
+"""
+Google Drive utilities for the Urarovite validation library.
+
+This module provides consolidated functionality for:
+- File ID extraction from various Google URLs
+- File type detection and metadata retrieval
+- File operations (download, upload, duplicate, move)
+- Authentication and service creation
+"""
+
 import re
-from typing import Any, Dict, List, Optional
+import logging
+from typing import Any, Dict, List, Optional, Union
+from pathlib import Path
 
 from googleapiclient.errors import HttpError
 
+# Configure logging
+logger = logging.getLogger(__name__)
+
+# URL pattern constants
 FOLDER_ID_RE = re.compile(r"/folders/([a-zA-Z0-9-_]+)")
 QUERY_ID_RE = re.compile(r"[?&]id=([a-zA-Z0-9-_]+)")
+FILE_ID_PATTERNS = [
+    r"/d/([a-zA-Z0-9_-]{10,})",  # /d/<id>/
+    r"id=([a-zA-Z0-9_-]{10,})",  # ?id=<id>
+    r"spreadsheets/d/([a-zA-Z0-9_-]{10,})",  # spreadsheets/d/<id>
+    r"drive/folders/([a-zA-Z0-9_-]{10,})",  # folders/<id>
+]
+
+# MIME type constants
+GOOGLE_SHEETS_MIMETYPE = "application/vnd.google-apps.spreadsheet"
+EXCEL_MIMETYPES = [
+    "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",  # .xlsx
+    "application/vnd.ms-excel",  # .xls
+    "application/vnd.ms-excel.sheet.macroEnabled.12",  # .xlsm
+]
+
+
+# Standard response structure
+def _create_response(success: bool, **kwargs) -> Dict[str, Any]:
+    """Create a standardized response dictionary."""
+    response = {"success": success}
+    response.update(kwargs)
+    return response
+
+
+def _extract_auth_secret(auth_credentials: Union[Dict[str, Any], str]) -> Optional[str]:
+    """Extract auth secret from various credential formats."""
+    if isinstance(auth_credentials, str):
+        return auth_credentials
+
+    # Try different possible keys
+    for key in ["auth_secret", "encoded_credentials", "encoded_creds"]:
+        if key in auth_credentials:
+            return auth_credentials[key]
+
+    return None
 
 
 def extract_folder_id(url: str | None) -> Optional[str]:
+    """Extract folder ID from Google Drive folder URL.
+
+    Args:
+        url: Google Drive folder URL
+
+    Returns:
+        Folder ID if found, None otherwise
+    """
     if not url:
         return None
+
     match = FOLDER_ID_RE.search(url)
     if match:
         return match.group(1)
+
     match = QUERY_ID_RE.search(url)
     return match.group(1) if match else None
 
 
 def extract_google_file_id(url: str) -> str | None:
-    patterns = [
-        r"/d/([a-zA-Z0-9_-]{10,})",  # /d/<id>/
-        r"id=([a-zA-Z0-9_-]{10,})",  # ?id=<id>
-        r"spreadsheets/d/([a-zA-Z0-9_-]{10,})",  # spreadsheets/d/<id>
-        r"drive/folders/([a-zA-Z0-9_-]{10,})",  # folders/<id>
-    ]
+    """Extract Google Drive file ID from various URL formats.
 
-    for pattern in patterns:
+    Args:
+        url: Google Drive file URL
+
+    Returns:
+        File ID if found, None otherwise
+    """
+    for pattern in FILE_ID_PATTERNS:
         match = re.search(pattern, url)
         if match:
             return match.group(1)
     return None
 
 
-def get_parent_folder_id(sheets_url: str, auth_secret: str) -> Optional[str]:
-    """Get the parent folder ID of a Google Sheets document.
+# Function removed - was unused
+
+
+def get_file_metadata(
+    file_url: str, auth_credentials: Union[Dict[str, Any], str]
+) -> Dict[str, Any]:
+    """Get metadata for a Google Drive file including mimetype.
 
     Args:
-        sheets_url: URL of the Google Sheets document
-        auth_secret: Base64 encoded service account credentials
+        file_url: Google Drive file URL
+        auth_credentials: Authentication credentials (dict with 'auth_secret' key or raw secret)
 
     Returns:
-        Parent folder ID, or None if not found
+        Dict containing file metadata or error info
 
-    Raises:
-        Exception: If unable to access the file or Drive API
+    Example:
+        {
+            "success": True,
+            "id": "1ABC123...",
+            "name": "My Spreadsheet",
+            "mimeType": "application/vnd.google-apps.spreadsheet",
+            "is_google_sheets": True,
+            "is_excel": False,
+            "is_supported_spreadsheet": True
+        }
     """
     from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
 
-    # Extract file ID from the URL
-    file_id = extract_google_file_id(sheets_url)
-    if not file_id:
-        return None
-
     try:
+        # Extract file ID from URL
+        file_id = extract_google_file_id(file_url)
+        if not file_id:
+            return _create_response(
+                False,
+                error="invalid_url",
+                error_msg="Could not extract file ID from URL",
+            )
+
+        # Extract auth secret
+        auth_secret = _extract_auth_secret(auth_credentials)
+        if not auth_secret:
+            return _create_response(
+                False,
+                error="no_auth",
+                error_msg="No authentication credentials provided",
+            )
+
         # Create Drive service
         drive_service = create_drive_service_from_encoded_creds(auth_secret)
 
-        # Get file metadata including parents
+        # Get file metadata
         file_metadata = (
-            drive_service.files().get(fileId=file_id, fields="parents").execute()
+            drive_service.files()
+            .get(
+                fileId=file_id,
+                fields="id,name,mimeType,parents,driveId",
+                supportsAllDrives=True,
+            )
+            .execute()
         )
 
-        # Return the first parent folder ID (files can have multiple parents but usually have one)
-        parents = file_metadata.get("parents", [])
-        return parents[0] if parents else None
+        mime_type = file_metadata.get("mimeType", "")
+
+        # Classify file type
+        is_google_sheets = mime_type == GOOGLE_SHEETS_MIMETYPE
+        is_excel = mime_type in EXCEL_MIMETYPES
+        is_supported_spreadsheet = is_google_sheets or is_excel
+
+        return _create_response(
+            True,
+            id=file_metadata.get("id"),
+            name=file_metadata.get("name", "Unknown"),
+            mimeType=mime_type,
+            is_google_sheets=is_google_sheets,
+            is_excel=is_excel,
+            is_supported_spreadsheet=is_supported_spreadsheet,
+            parents=file_metadata.get("parents", []),
+            driveId=file_metadata.get("driveId"),
+        )
+
+    except HttpError as e:
+        error_code = f"http_{e.resp.status}"
+        error_msg = str(e)
+
+        return _create_response(False, error=error_code, error_msg=error_msg)
 
     except Exception as e:
-        # Log the error but don't fail completely
-        import logging
+        return _create_response(
+            False, error=f"exception_{e.__class__.__name__}", error_msg=str(e)
+        )
 
-        logging.warning(f"Failed to get parent folder for {sheets_url}: {str(e)}")
-        return None
+
+def download_file_from_drive(
+    file_url: str, local_path: str, auth_credentials: Union[Dict[str, Any], str]
+) -> Dict[str, Any]:
+    """Download a file from Google Drive to local disk.
+
+    Args:
+        file_url: Google Drive file URL
+        local_path: Local path where the file should be saved
+        auth_credentials: Authentication credentials (dict with 'auth_secret' key or raw secret)
+
+    Returns:
+        Dict with success status and error info if applicable
+    """
+    from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
+    from googleapiclient.http import MediaIoBaseDownload
+    import io
+
+    try:
+        # Extract file ID from URL
+        file_id = extract_google_file_id(file_url)
+        if not file_id:
+            return _create_response(False, error="Could not extract file ID from URL")
+
+        # Extract auth secret
+        auth_secret = _extract_auth_secret(auth_credentials)
+        if not auth_secret:
+            return _create_response(
+                False, error="No auth_secret found in auth_credentials"
+            )
+
+        # Create Drive service
+        drive_service = create_drive_service_from_encoded_creds(auth_secret)
+
+        # Download the file
+        request = drive_service.files().get_media(fileId=file_id)
+
+        fh = io.BytesIO()
+        downloader = MediaIoBaseDownload(fh, request)
+
+        done = False
+        while not done:
+            status, done = downloader.next_chunk()
+
+        # Write to local file
+        with open(local_path, "wb") as f:
+            f.write(fh.getvalue())
+
+        return _create_response(True, local_path=local_path)
+
+    except Exception as e:
+        return _create_response(False, error=f"Failed to download file: {str(e)}")
+
+
+def upload_file_to_drive_folder(
+    file_path: str,
+    filename: str,
+    folder_id: str,
+    auth_credentials: Union[Dict[str, Any], str],
+) -> Dict[str, Any]:
+    """Upload a local file to a Google Drive folder.
+
+    Args:
+        file_path: Local path to the file to upload
+        filename: Name to give the file in Drive
+        folder_id: Google Drive folder ID where the file will be uploaded
+        auth_credentials: Authentication credentials (dict with 'auth_secret' key or raw secret)
+
+    Returns:
+        Dict with keys:
+        - success: Boolean indicating if upload succeeded
+        - file_id: The ID of the uploaded file when successful, else None
+        - file_url: URL of the uploaded file when successful, else None
+        - error: Error message on failure, otherwise None
+    """
+    from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
+    from googleapiclient.http import MediaFileUpload
+    import os
+
+    try:
+        # Validate inputs
+        if not os.path.exists(file_path):
+            return _create_response(
+                False,
+                file_id=None,
+                file_url=None,
+                error=f"Local file not found: {file_path}",
+            )
+
+        if not folder_id:
+            return _create_response(
+                False, file_id=None, file_url=None, error="No folder ID provided"
+            )
+
+        # Extract auth secret
+        auth_secret = _extract_auth_secret(auth_credentials)
+        if not auth_secret:
+            return _create_response(
+                False,
+                file_id=None,
+                file_url=None,
+                error="No authentication credentials provided",
+            )
+
+        # Create Drive service
+        drive_service = create_drive_service_from_encoded_creds(auth_secret)
+
+        # Prepare file metadata
+        file_metadata = {"name": filename, "parents": [folder_id]}
+
+        # Create media upload object
+        media = MediaFileUpload(file_path, resumable=True)
+
+        # Upload the file
+        file = (
+            drive_service.files()
+            .create(
+                body=file_metadata,
+                media_body=media,
+                fields="id, webViewLink",
+                supportsAllDrives=True,
+            )
+            .execute()
+        )
+
+        return _create_response(
+            True, file_id=file.get("id"), file_url=file.get("webViewLink"), error=None
+        )
+
+    except Exception as e:
+        return _create_response(False, file_id=None, file_url=None, error=str(e))
 
 
 def duplicate_file_to_drive_folder(
@@ -101,16 +346,13 @@ def duplicate_file_to_drive_folder(
     file_id = extract_google_file_id(file_url)
 
     if not file_id:
-        return {"success": False, "id": None, "url": None, "error": "Invalid file url"}
+        return _create_response(False, id=None, url=None, error="Invalid file url")
 
     folder_id = extract_folder_id(folder_url)
     if not folder_id:
-        return {
-            "success": False,
-            "id": None,
-            "url": None,
-            "error": "missing_or_malformed_url",
-        }
+        return _create_response(
+            False, id=None, url=None, error="missing_or_malformed_url"
+        )
 
     try:
         src = (
@@ -122,7 +364,7 @@ def duplicate_file_to_drive_folder(
         src_mime = src.get("mimeType", "")
 
         # Get the proper filename - use spreadsheet title for Google Sheets if possible
-        if src_mime == "application/vnd.google-apps.spreadsheet" and sheets_service:
+        if src_mime == GOOGLE_SHEETS_MIMETYPE and sheets_service:
             try:
                 # Get actual spreadsheet title from Sheets API
                 spreadsheet_metadata = (
@@ -158,6 +400,26 @@ def duplicate_file_to_drive_folder(
         if prefix_file_name:
             name = f"{prefix_file_name}{name}"
 
+        # Handle duplicate names by adding (1), (2), etc.
+        original_name = name
+        counter = 1
+        while True:
+            # Check if file with this name already exists in the folder
+            query = f"name='{name}' and '{folder_id}' in parents and trashed=false"
+            existing_files = (
+                drive_service.files()
+                .list(q=query, fields="files(id,name)", supportsAllDrives=True)
+                .execute()
+            )
+
+            if not existing_files.get("files"):
+                # Name is unique, use it
+                break
+
+            # Name exists, try next number
+            name = f"{original_name} ({counter})"
+            counter += 1
+
         body = {"name": name, "parents": [folder_id]}
         dup = (
             drive_service.files()
@@ -172,7 +434,7 @@ def duplicate_file_to_drive_folder(
 
         new_id = dup.get("id")
 
-        if src_mime == "application/vnd.google-apps.spreadsheet":
+        if src_mime == GOOGLE_SHEETS_MIMETYPE:
             new_url = f"https://docs.google.com/spreadsheets/d/{new_id}/edit"
         else:
             new_url = (
@@ -180,204 +442,240 @@ def duplicate_file_to_drive_folder(
                 or f"https://drive.google.com/file/d/{new_id}/view"
             )
 
-        return {"success": True, "id": new_id, "url": new_url, "error": None}
+        return _create_response(True, id=new_id, url=new_url, error=None)
 
     except Exception as e:
         msg = str(e)
         if "HttpError 403" in msg or "HttpError 404" in msg:
-            return {
-                "success": False,
-                "id": None,
-                "url": None,
-                "error": "forbidden_or_not_found",
-                "error_msg": msg,
-            }
-        return {
-            "success": False,
-            "id": None,
-            "url": None,
-            "error": f"request_exception:{e.__class__.__name__}",
-            "error_msg": msg,
-        }
-
-
-def move_sheets_to_folder(
-    drive_service: Any,
-    sheet_urls: List[str],
-    folder_url: str,
-) -> List[Dict[str, Any]]:
-    """
-    Move files to the destination folder.
-    - If only_google_sheets=True, skips non‑Sheets files.
-    - Works with My Drive and Shared drives (if you have permission).
-
-    Returns:
-        List of dictionaries, one for each file, with keys:
-        - success: Boolean
-        - id: The ID of the moved file when successful, else None.
-        - name: Name of the file when successful, else None.
-        - error: Error code string on failure, otherwise None.
-        - error_msg: Optional raw error message from the API when available.
-    """
-    results = []
-
-    # Extract folder ID from URL
-    folder_id = extract_folder_id(folder_url)
-    if not folder_id:
-        # Return error for all files if folder URL is invalid
-        return [
-            {
-                "success": False,
-                "id": None,
-                "name": None,
-                "error": "missing_or_malformed_folder_url",
-                "error_msg": f"Could not extract folder ID from: {folder_url}",
-            }
-            for _ in sheet_urls
-        ]
-
-    # We'll set supportsAllDrives on read & write in case of Shared drives
-    for sheet_url in sheet_urls:
-        # Extract file ID from URL
-        file_id = extract_google_file_id(sheet_url)
-        if not file_id:
-            results.append(
-                {
-                    "success": False,
-                    "id": None,
-                    "name": None,
-                    "error": "invalid_file_url",
-                    "error_msg": f"Could not extract file ID from: {sheet_url}",
-                }
+            return _create_response(
+                False,
+                id=None,
+                url=None,
+                error="forbidden_or_not_found",
+                error_msg=msg,
             )
-            continue
-
-        try:
-            file = (
-                drive_service.files()
-                .get(
-                    fileId=file_id,
-                    fields="id, name, parents, mimeType, driveId",
-                    supportsAllDrives=True,
-                )
-                .execute()
-            )
-
-            name = file.get("name", "Unknown")
-            parents = file.get("parents", [])
-
-            add_parents = folder_id
-            remove_parents = ",".join(parents) if parents else ""
-
-            drive_service.files().update(
-                fileId=file_id,
-                addParents=add_parents,
-                removeParents=remove_parents,
-                fields="id, name, parents",
-                supportsAllDrives=True,
-            ).execute()
-
-            results.append(
-                {
-                    "success": True,
-                    "id": file_id,
-                    "name": name,
-                    "error": None,
-                    "error_msg": None,
-                }
-            )
-
-        except HttpError as e:
-            # Helpful error context
-            status = getattr(e, "status_code", None) or getattr(e, "resp", {}).get(
-                "status"
-            )
-            error_msg = f"HTTP {status} - {e}"
-
-            if status in [403, 404]:
-                error_code = "forbidden_or_not_found"
-            else:
-                error_code = f"http_error_{status}"
-
-            results.append(
-                {
-                    "success": False,
-                    "id": file_id,
-                    "name": None,
-                    "error": error_code,
-                    "error_msg": error_msg,
-                }
-            )
-
-        except Exception as e:
-            results.append(
-                {
-                    "success": False,
-                    "id": file_id,
-                    "name": None,
-                    "error": f"request_exception:{e.__class__.__name__}",
-                    "error_msg": str(e),
-                }
-            )
-
-    return results
+        return _create_response(
+            False,
+            id=None,
+            url=None,
+            error=f"request_exception:{e.__class__.__name__}",
+            error_msg=msg,
+        )
 
 
-def download_file_from_drive(
-    file_url: str, local_path: str, auth_credentials: Dict[str, Any]
-) -> Dict[str, Any]:
-    """Download a file from Google Drive to local disk.
+def get_original_folder_id(
+    file_url: str, auth_credentials: Union[Dict[str, Any], str]
+) -> str:
+    """Get the original folder ID where a file is located.
 
     Args:
-        file_url: Google Drive file URL
-        local_path: Local path where the file should be saved
-        auth_credentials: Authentication credentials (dict with 'auth_secret' key)
+        file_url: Google Drive file URL (Google Sheets, Excel, etc.)
+        auth_credentials: Authentication credentials (dict with 'auth_secret' key or raw secret)
 
     Returns:
-        Dict with success status and error info if applicable
+        Folder ID string if found, None otherwise
     """
-    from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
-    from googleapiclient.http import MediaIoBaseDownload
-    import io
-
     try:
+        from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
+
         # Extract file ID from URL
         file_id = extract_google_file_id(file_url)
         if not file_id:
-            return {"success": False, "error": "Could not extract file ID from URL"}
+            return None
 
-        # Get auth secret from credentials
-        if isinstance(auth_credentials, dict):
-            auth_secret = auth_credentials.get("auth_secret")
-            if not auth_secret:
-                return {
-                    "success": False,
-                    "error": "No auth_secret found in auth_credentials",
-                }
-        else:
-            auth_secret = auth_credentials
+        # Extract auth secret
+        auth_secret = _extract_auth_secret(auth_credentials)
+        if not auth_secret:
+            return None
 
         # Create Drive service
         drive_service = create_drive_service_from_encoded_creds(auth_secret)
 
-        # Download the file
-        request = drive_service.files().get_media(fileId=file_id)
+        # Get file metadata
+        file = (
+            drive_service.files()
+            .get(fileId=file_id, fields="parents", supportsAllDrives=True)
+            .execute()
+        )
 
-        fh = io.BytesIO()
-        downloader = MediaIoBaseDownload(fh, request)
+        parents = file.get("parents", [])
+        if parents:
+            return parents[0]  # Return first parent folder
 
-        done = False
-        while not done:
-            status, done = downloader.next_chunk()
+        return None
 
-        # Write to local file
-        with open(local_path, "wb") as f:
-            f.write(fh.getvalue())
+    except Exception:
+        return None
 
-        return {"success": True, "local_path": local_path}
+
+def extract_original_filename_from_source(
+    source_url_or_path: str,
+    auth_credentials: Union[Dict[str, Any], str],
+    downloaded_file_path: str = None,
+) -> Dict[str, Any]:
+    """Extract the original filename from various spreadsheet sources using existing utilities.
+
+    This function consolidates filename extraction logic from multiple sources:
+    1. Custom filename (if provided)
+    2. Google Sheets API title (for spreadsheet URLs)
+    3. Excel file content (first sheet name)
+    4. Drive API metadata
+    5. Local file path
+    6. Fallback names
+
+    Args:
+        source_url_or_path: URL or file path to extract filename from
+        auth_credentials: Authentication credentials (dict with 'auth_secret' key or raw secret)
+        downloaded_file_path: Optional path to downloaded Excel file for content extraction
+
+    Returns:
+        Dict with keys:
+        - success: Boolean indicating if extraction succeeded
+        - filename: Extracted filename if successful, else fallback name
+        - source: String indicating which method was used
+        - error: Error message on failure, otherwise None
+    """
+    try:
+        from urarovite.auth.google_sheets import (
+            create_sheets_service_from_encoded_creds,
+        )
+
+        # Try Google Sheets API title first (most reliable for spreadsheets)
+        file_id = extract_google_file_id(source_url_or_path)
+        if file_id and source_url_or_path.startswith("http"):
+            try:
+                auth_secret = _extract_auth_secret(auth_credentials)
+                if auth_secret:
+                    sheets_service = create_sheets_service_from_encoded_creds(
+                        auth_secret
+                    )
+
+                    # Get actual spreadsheet title from Sheets API
+                    spreadsheet_metadata = (
+                        sheets_service.spreadsheets()
+                        .get(spreadsheetId=file_id, fields="properties.title")
+                        .execute()
+                    )
+                    spreadsheet_title = spreadsheet_metadata.get("properties", {}).get(
+                        "title", ""
+                    )
+
+                    if spreadsheet_title:
+                        # For Google Sheets, preserve the full original title
+                        # Only replace truly invalid characters that Google Sheets doesn't allow
+                        invalid_chars = '<>:"/\\|?*'
+                        if any(char in spreadsheet_title for char in invalid_chars):
+                            filename = "".join(
+                                c if c not in invalid_chars else "_"
+                                for c in spreadsheet_title
+                            ).rstrip()
+                        else:
+                            filename = spreadsheet_title
+
+                        return _create_response(
+                            True,
+                            filename=filename,
+                            source="sheets_api_title",
+                            error=None,
+                        )
+            except Exception:
+                # Continue to next method
+                pass
+
+        # Try to get original name from Drive API metadata first (before Excel content)
+        # This helps when we have an Excel file that was converted from Google Sheets
+        if file_id:
+            try:
+                metadata = get_file_metadata(source_url_or_path, auth_credentials)
+                if metadata.get("success") and metadata.get("name"):
+                    original_name = metadata["name"]
+                    # Remove extension if present
+                    if original_name.endswith(".xlsx"):
+                        original_name = original_name[:-5]
+                    elif original_name.endswith(".xls"):
+                        original_name = original_name[:-4]
+
+                    # For Google Sheets, use more permissive naming (preserve more characters)
+                    # Google Sheets allows more characters than filesystem-safe names
+                    invalid_chars = '<>:"/\\|?*'
+                    if any(char in original_name for char in invalid_chars):
+                        filename = "".join(
+                            c if c not in invalid_chars else "_" for c in original_name
+                        ).rstrip()
+                    else:
+                        filename = original_name
+
+                    # Clean up common conversion suffixes that might have been added
+                    # Remove patterns like "_excel_1", "_excel_2", etc.
+                    import re
+
+                    filename = re.sub(r"_excel_\d+$", "", filename)
+                    # Remove patterns like "_1", "_2" at the end if they look like conversion suffixes
+                    filename = re.sub(r"_\d+$", "", filename)
+
+                    return _create_response(
+                        True, filename=filename, source="drive_metadata", error=None
+                    )
+            except Exception:
+                # Continue to next method
+                pass
+
+        # Try Excel content extraction (for downloaded files)
+        if downloaded_file_path:
+            try:
+                import pandas as pd
+
+                excel_file = pd.ExcelFile(downloaded_file_path)
+                if excel_file.sheet_names:
+                    first_sheet = excel_file.sheet_names[0]
+                    # For Google Sheets, use more permissive naming (preserve more characters)
+                    # Google Sheets allows more characters than filesystem-safe names
+                    invalid_chars = '<>:"/\\|?*'
+                    if any(char in first_sheet for char in invalid_chars):
+                        filename = "".join(
+                            c if c not in invalid_chars else "_" for c in first_sheet
+                        ).rstrip()
+                    else:
+                        filename = first_sheet
+
+                    if filename and filename != "unnamed_sheet":
+                        return _create_response(
+                            True, filename=filename, source="excel_content", error=None
+                        )
+            except Exception:
+                # Continue to next method
+                pass
+
+        # Try local file path
+        if not source_url_or_path.startswith("http"):
+            import pathlib
+
+            filename = pathlib.Path(source_url_or_path).stem
+            if filename:
+                return _create_response(
+                    True, filename=filename, source="local_file", error=None
+                )
+
+        # Fallback names
+        if file_id:
+            fallback_name = f"Excel_File_{file_id[:8]}"
+        else:
+            fallback_name = "Converted_Excel_File"
+
+        return _create_response(
+            True,
+            filename=fallback_name,
+            source="fallback",
+            error="Could not extract original filename, using fallback",
+        )
 
     except Exception as e:
-        return {"success": False, "error": f"Failed to download file: {str(e)}"}
+        return _create_response(
+            False,
+            filename="Converted_Excel_File",
+            source="error_fallback",
+            error=str(e),
+        )
 
 
 def detect_spreadsheet_type(
@@ -416,11 +714,6 @@ def detect_spreadsheet_type(
         >>> print(result["file_type"])  # "google_sheets"
         >>> print(result["is_supported"])  # True
     """
-    import logging
-    from pathlib import Path
-
-    logger = logging.getLogger(__name__)
-
     # Initialize result structure
     result = {
         "file_type": "unknown",
@@ -460,7 +753,7 @@ def detect_spreadsheet_type(
                     mime_type = metadata_result.get("mimeType", "")
                     result["metadata"] = metadata_result
 
-                    if mime_type == "application/vnd.google-apps.spreadsheet":
+                    if mime_type == GOOGLE_SHEETS_MIMETYPE:
                         result.update(
                             {
                                 "file_type": "google_sheets",
@@ -468,11 +761,7 @@ def detect_spreadsheet_type(
                                 "is_supported": True,
                             }
                         )
-                    elif mime_type in [
-                        "application/vnd.openxmlformats-officedocument."
-                        "spreadsheetml.sheet",  # .xlsx
-                        "application/vnd.ms-excel",  # .xls
-                    ]:
+                    elif mime_type in EXCEL_MIMETYPES:
                         result.update(
                             {
                                 "file_type": "excel_from_drive",
@@ -528,7 +817,7 @@ def detect_spreadsheet_type(
                     mime_type = metadata_result.get("mimeType", "")
                     result["metadata"] = metadata_result
 
-                    if mime_type == "application/vnd.google-apps.spreadsheet":
+                    if mime_type == GOOGLE_SHEETS_MIMETYPE:
                         result.update(
                             {
                                 "file_type": "google_sheets",
@@ -536,11 +825,7 @@ def detect_spreadsheet_type(
                                 "is_supported": True,
                             }
                         )
-                    elif mime_type in [
-                        "application/vnd.openxmlformats-officedocument."
-                        "spreadsheetml.sheet",  # .xlsx
-                        "application/vnd.ms-excel",  # .xls
-                    ]:
+                    elif mime_type in EXCEL_MIMETYPES:
                         result.update(
                             {
                                 "file_type": "excel_from_drive",
@@ -639,84 +924,6 @@ def detect_spreadsheet_type(
     return result
 
 
-def get_file_metadata(file_url: str, auth_secret: str) -> Dict[str, Any]:
-    """Get metadata for a Google Drive file including mimetype.
-
-    Args:
-        file_url: Google Drive file URL
-        auth_secret: Base64 encoded service account credentials
-
-    Returns:
-        Dict containing file metadata or error info
-
-    Example:
-        {
-            "success": True,
-            "id": "1ABC123...",
-            "name": "My Spreadsheet",
-            "mimeType": "application/vnd.google-apps.spreadsheet",
-            "is_google_sheets": True,
-            "is_excel": False,
-            "is_supported_spreadsheet": True
-        }
-    """
-    from urarovite.auth.google_drive import create_drive_service_from_encoded_creds
-
-    try:
-        # Extract file ID from URL
-        file_id = extract_google_file_id(file_url)
-        if not file_id:
-            return {
-                "success": False,
-                "error": "invalid_url",
-                "error_msg": "Could not extract file ID from URL",
-            }
-
-        # Create Drive service
-        drive_service = create_drive_service_from_encoded_creds(auth_secret)
-
-        # Get file metadata
-        file_metadata = (
-            drive_service.files()
-            .get(
-                fileId=file_id,
-                fields="id,name,mimeType,parents,driveId",
-                supportsAllDrives=True,
-            )
-            .execute()
-        )
-
-        mime_type = file_metadata.get("mimeType", "")
-
-        # Classify file type
-        is_google_sheets = mime_type == "application/vnd.google-apps.spreadsheet"
-        is_excel = mime_type in [
-            "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",  # .xlsx
-            "application/vnd.ms-excel",  # .xls
-        ]
-        is_supported_spreadsheet = is_google_sheets or is_excel
-
-        return {
-            "success": True,
-            "id": file_metadata.get("id"),
-            "name": file_metadata.get("name", "Unknown"),
-            "mimeType": mime_type,
-            "is_google_sheets": is_google_sheets,
-            "is_excel": is_excel,
-            "is_supported_spreadsheet": is_supported_spreadsheet,
-            "parents": file_metadata.get("parents", []),
-            "driveId": file_metadata.get("driveId"),
-        }
-
-    except HttpError as e:
-        error_code = f"http_{e.resp.status}"
-        error_msg = str(e)
-
-        return {"success": False, "error": error_code, "error_msg": error_msg}
-
-    except Exception as e:
-        return {
-            "success": False,
-            "error": f"exception_{e.__class__.__name__}",
-            "error_msg": str(e),
-        }
+# Backward compatibility aliases
+download_drive_file = download_file_from_drive
+get_drive_file_metadata = get_file_metadata
