@@ -11,6 +11,16 @@ from pathlib import Path
 
 logger = logging.getLogger(__name__)
 
+# Set logging level for this module to reduce noise from formatting extraction
+# Only show warnings for actual errors, not for cells without styles
+if logger.level == logging.NOTSET:
+    logger.setLevel(logging.INFO)
+
+# Configuration for formatting extraction behavior
+FORMATTING_EXTRACTION_VERBOSE = False  # Set to True for detailed logging
+FORMATTING_EXTRACTION_SKIP_EMPTY = True  # Skip cells that are definitely empty
+FORMATTING_EXTRACTION_MAX_WARNINGS = 10  # Limit warning messages per sheet
+
 try:
     from openpyxl.styles import Font, Fill, Border, Alignment, PatternFill
     from openpyxl.styles.colors import Color
@@ -75,14 +85,39 @@ class FormatExtractor:
             cell_formats = {}
 
             # Iterate through all cells that have data or formatting
+            cells_processed = 0
+            cells_with_formatting = 0
+            warning_count = 0
+
             for row in worksheet.iter_rows():
                 for cell in row:
-                    if cell.value is not None or self._has_formatting(cell):
-                        cell_ref = cell.coordinate
-                        cell_formats[cell_ref] = self._extract_excel_cell_format(cell)
+                    # Skip cells that are definitely empty and unformatted (configurable)
+                    if (
+                        FORMATTING_EXTRACTION_SKIP_EMPTY
+                        and cell.value is None
+                        and not self._has_formatting(cell)
+                    ):
+                        continue
+
+                    cells_processed += 1
+                    cell_ref = cell.coordinate
+                    cell_formats[cell_ref] = self._extract_excel_cell_format(cell)
+
+                    # Count cells that actually have formatting
+                    if self._has_formatting(cell):
+                        cells_with_formatting += 1
+
+                    # Limit warning messages if configured
+                    if warning_count >= FORMATTING_EXTRACTION_MAX_WARNINGS:
+                        if warning_count == FORMATTING_EXTRACTION_MAX_WARNINGS:
+                            logger.info(
+                                f"Suppressing additional formatting warnings for {sheet_name}"
+                            )
+                        break
 
             logger.info(
-                f"Extracted formatting for {len(cell_formats)} cells from {sheet_name}"
+                f"Extracted formatting for {len(cell_formats)} cells from {sheet_name} "
+                f"(processed {cells_processed}, {cells_with_formatting} had formatting)"
             )
             return cell_formats
 
@@ -93,44 +128,46 @@ class FormatExtractor:
     def _has_formatting(self, cell: Any) -> bool:
         """Check if a cell has any formatting applied."""
         try:
-            # Check for non-default font
-            if (
-                cell.font.name != "Calibri"
-                or cell.font.size != 11
-                or cell.font.bold
-                or cell.font.italic
-            ):
-                return True
+            # Safely check font properties
+            if hasattr(cell, "font") and cell.font:
+                if (
+                    getattr(cell.font, "name", "Calibri") != "Calibri"
+                    or getattr(cell.font, "size", 11) != 11
+                    or getattr(cell.font, "bold", False)
+                    or getattr(cell.font, "italic", False)
+                ):
+                    return True
 
-            # Check for background color (be more strict about what counts as formatting)
-            if (
-                hasattr(cell.fill, "fgColor")
-                and cell.fill.fgColor
-                and cell.fill.fgColor.rgb
-                and cell.fill.fgColor.rgb != "00000000"  # Not black/default
-                and cell.fill.fgColor.rgb != "FFFFFFFF"  # Not white/default
-                and cell.fill.fgColor.rgb != "FF000000"  # Not default black
-                and len(cell.fill.fgColor.rgb) == 8  # Valid RGB format
-                and cell.fill.fill_type  # Has actual fill type
-                and cell.fill.fill_type != "none"
-            ):  # Not "no fill"
-                return True
+            # Safely check background color
+            if hasattr(cell, "fill") and cell.fill:
+                if hasattr(cell.fill, "fgColor") and cell.fill.fgColor:
+                    rgb = getattr(cell.fill.fgColor, "rgb", None)
+                    fill_type = getattr(cell.fill, "fill_type", None)
+                    if (
+                        rgb
+                        and rgb != "00000000"  # Not black/default
+                        and rgb != "FFFFFFFF"  # Not white/default
+                        and rgb != "FF000000"  # Not default black
+                        and len(rgb) == 8  # Valid RGB format
+                        and fill_type  # Has actual fill type
+                        and fill_type != "none"
+                    ):  # Not "no fill"
+                        return True
 
-            # Check for borders
-            if (
-                cell.border.top.style
-                or cell.border.bottom.style
-                or cell.border.left.style
-                or cell.border.right.style
-            ):
-                return True
+            # Safely check borders
+            if hasattr(cell, "border") and cell.border:
+                for border_side in ["top", "bottom", "left", "right"]:
+                    border = getattr(cell.border, border_side, None)
+                    if border and getattr(border, "style", None):
+                        return True
 
-            # Check for alignment
-            if (
-                cell.alignment.horizontal != "general"
-                or cell.alignment.vertical != "bottom"
-            ):
-                return True
+            # Safely check alignment
+            if hasattr(cell, "alignment") and cell.alignment:
+                if (
+                    getattr(cell.alignment, "horizontal", "general") != "general"
+                    or getattr(cell.alignment, "vertical", "bottom") != "bottom"
+                ):
+                    return True
 
             return False
 
@@ -186,7 +223,10 @@ class FormatExtractor:
             return format_obj
 
         except Exception as e:
-            logger.warning(f"Failed to extract cell format: {e}")
+            # Only log warnings for actual errors, not for cells without styles
+            if FORMATTING_EXTRACTION_VERBOSE:
+                if "NoneType" not in str(e) and "has no attribute" not in str(e):
+                    logger.debug(f"Failed to extract cell format: {e}")
             return CellFormat()
 
     def _excel_color_to_hex(self, color: Any) -> Optional[str]:
