@@ -5,6 +5,8 @@ to work seamlessly with both Google Sheets and Excel files.
 """
 
 import json
+import logging
+import re
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Union
 
@@ -12,6 +14,121 @@ from urarovite.core.spreadsheet import SpreadsheetFactory
 from urarovite.core.exceptions import ValidationError
 
 
+def check_spreadsheet_access(
+    spreadsheet_source: Union[str, Path],
+    auth_credentials: Optional[Dict[str, Any]] = None,
+) -> Dict[str, Any]:
+    """Check if a spreadsheet is accessible and get basic metadata.
+
+    This function attempts to access a spreadsheet (Google Sheets or Excel) and returns
+    information about its accessibility, including file type, basic metadata, and any
+    errors.
+
+    Args:
+        spreadsheet_source: Google Sheets URL or Excel file path
+        auth_credentials: Authentication credentials (required for Google Sheets)
+
+    Returns:
+        Dict with keys:
+            - accessible: bool - Whether the spreadsheet is accessible
+            - file_type: str - Type of file ('google_sheets', 'excel_from_drive',
+              'local_excel')
+            - metadata: Optional[Dict] - Basic metadata if accessible
+            - tabs: List[str] - List of tab names if accessible
+            - error: Optional[str] - Error message if not accessible
+            - details: Dict - Additional details about the access attempt
+    """
+    try:
+        # First, try to detect the file type
+        from urarovite.utils.drive import detect_spreadsheet_type
+
+        detection_result = detect_spreadsheet_type(spreadsheet_source, auth_credentials)
+        file_type = detection_result.get("file_type", "unknown")
+
+        # Try to create and access the spreadsheet
+        with SpreadsheetFactory.create_spreadsheet(
+            spreadsheet_source, auth_credentials
+        ) as spreadsheet:
+            # Get basic metadata
+            metadata = spreadsheet.get_metadata()
+            tabs = metadata.sheet_names if metadata else []
+
+            # Get additional details
+            details = {
+                "file_type": file_type,
+                "is_google_sheets": detection_result.get("is_google_sheets", False),
+                "file_id": detection_result.get("file_id"),
+                "file_name": detection_result.get("file_name"),
+                "mime_type": detection_result.get("mime_type"),
+                "size_bytes": detection_result.get("size_bytes"),
+                "created_time": detection_result.get("created_time"),
+                "modified_time": detection_result.get("modified_time"),
+                "permissions": detection_result.get("permissions", {}),
+            }
+
+            return {
+                "accessible": True,
+                "file_type": file_type,
+                "metadata": {
+                    "sheet_names": tabs,
+                    "total_sheets": len(tabs),
+                    "spreadsheet_id": metadata.spreadsheet_id if metadata else None,
+                    "title": metadata.title if metadata else None,
+                    "spreadsheet_type": metadata.spreadsheet_type if metadata else None,
+                    "url": metadata.url if metadata else None,
+                    "file_path": str(metadata.file_path)
+                    if metadata and metadata.file_path
+                    else None,
+                },
+                "tabs": tabs,
+                "error": None,
+                "details": details,
+            }
+
+    except Exception as e:
+        # Extract error details
+        error_msg = str(e)
+        error_type = "unknown"
+
+        if "403" in error_msg or "Forbidden" in error_msg:
+            error_type = "permission_denied"
+        elif "404" in error_msg or "Not Found" in error_msg:
+            error_type = "not_found"
+        elif "401" in error_msg or "Unauthorized" in error_msg:
+            error_type = "authentication_failed"
+        elif "quota" in error_msg.lower():
+            error_type = "quota_exceeded"
+        elif "network" in error_msg.lower() or "timeout" in error_msg.lower():
+            error_type = "network_error"
+
+        # Handle case where detection_result might not exist
+        detection_file_type = "unknown"
+        detection_is_google_sheets = False
+        detection_file_id = None
+        detection_file_name = None
+
+        if "detection_result" in locals():
+            detection_file_type = detection_result.get("file_type", "unknown")
+            detection_is_google_sheets = detection_result.get("is_google_sheets", False)
+            detection_file_id = detection_result.get("file_id")
+            detection_file_name = detection_result.get("file_name")
+
+        return {
+            "accessible": False,
+            "file_type": "unknown",
+            "metadata": None,
+            "tabs": [],
+            "error": error_msg,
+            "error_type": error_type,
+            "details": {
+                "file_type": detection_file_type,
+                "is_google_sheets": detection_is_google_sheets,
+                "file_id": detection_file_id,
+                "file_name": detection_file_name,
+            },
+        }
+
+
 def get_spreadsheet_tabs(
     spreadsheet_source: Union[str, Path],
     auth_credentials: Optional[Dict[str, Any]] = None,
@@ -328,23 +445,31 @@ def convert_google_sheets_to_excel(
                         # Get data from Google Sheets
                         sheet_data = source_spreadsheet.get_sheet_data(sheet_name)
 
-                        # Create sheet in Excel file (only if it doesn't exist)
-                        if sheet_name not in existing_sheets:
-                            target_spreadsheet.create_sheet(sheet_name)
+                        # Create sheet in Excel file with truncated name (only if it doesn't exist)
+                        # The create_sheet method will automatically truncate the name to 31 characters
+                        excel_sheet_name = (
+                            sheet_name  # Will be truncated by create_sheet if needed
+                        )
+                        if excel_sheet_name not in existing_sheets:
+                            target_spreadsheet.create_sheet(excel_sheet_name)
+                            # Get the actual sheet name that was created (in case it was truncated)
+                            excel_sheet_name = (
+                                target_spreadsheet.get_metadata().sheet_names[-1]
+                            )
 
                         # Copy data (whether sheet existed or was just created)
                         if sheet_data.values:
                             target_spreadsheet.update_sheet_data(
-                                sheet_name, sheet_data.values
+                                excel_sheet_name, sheet_data.values
                             )
 
-                        converted_sheets.append(sheet_name)
+                        converted_sheets.append(excel_sheet_name)
 
                     except Exception as e:
                         # Log individual sheet errors but continue
-                        import logging
-
-                        logging.warning(f"Failed to convert sheet '{sheet_name}': {e}")
+                        logging.warning(
+                            f"Failed to convert sheet '{sheet_name}' (Excel name: '{excel_sheet_name}'): {e}"
+                        )
 
                 # Remove sheets that existed initially but weren't converted from source
                 if converted_sheets:
@@ -364,13 +489,9 @@ def convert_google_sheets_to_excel(
                         # Remove unused initial sheets
                         for sheet_name in sheets_to_remove:
                             target_spreadsheet.delete_sheet(sheet_name)
-                            import logging
-
                             logging.info(f"Removed unused initial sheet: {sheet_name}")
 
                     except Exception as e:
-                        import logging
-
                         logging.warning(f"Could not remove unused sheets: {e}")
 
                 # Save the Excel file
@@ -381,6 +502,8 @@ def convert_google_sheets_to_excel(
             "converted_sheets": converted_sheets,
             "output_path": str(excel_path),
             "error": None,
+            "original_sheet_names": sheets_to_convert,
+            "excel_sheet_names": converted_sheets,
         }
 
     except Exception as e:
@@ -462,13 +585,16 @@ def convert_excel_to_google_sheets_bulk(
         Dict with keys: success, converted_sheets, error
     """
     try:
-        from urarovite.utils.sheets import extract_sheet_id, create_new_spreadsheet_in_folder
+        from urarovite.utils.sheets import (
+            extract_sheet_id,
+            create_new_spreadsheet_in_folder,
+        )
         from urarovite.auth.google_sheets import (
             create_sheets_service_from_encoded_creds,
         )
 
         excel_path = Path(excel_file_path)
-        
+
         # Handle "auto" case - create new Google Sheet
         if google_sheets_url == "auto":
             # Extract auth credentials
@@ -478,24 +604,26 @@ def convert_excel_to_google_sheets_bulk(
                     raise ValidationError("No auth_secret found in auth_credentials")
             else:
                 encoded_creds = auth_credentials
-            
+
             # Create gspread client for new sheet creation
             import gspread
             from urarovite.auth.google_sheets import decode_service_account
-            
+
             service_account_info = decode_service_account(encoded_creds)
             gspread_client = gspread.service_account_from_dict(service_account_info)
-            
+
             # Create new spreadsheet with Excel filename as title
             spreadsheet_name = excel_path.stem
-            
+
             if drive_folder_id:
                 # Create in specified folder
                 new_spreadsheet = create_new_spreadsheet_in_folder(
                     gspread_client, drive_folder_id, spreadsheet_name
                 )
                 if not new_spreadsheet:
-                    raise ValidationError(f"Failed to create spreadsheet in folder {drive_folder_id}")
+                    raise ValidationError(
+                        f"Failed to create spreadsheet in folder {drive_folder_id}"
+                    )
             else:
                 # Service accounts can't create sheets in their own drive without proper permissions
                 raise ValidationError(
@@ -503,7 +631,7 @@ def convert_excel_to_google_sheets_bulk(
                     "where the service account has write access. Service accounts cannot "
                     "create sheets in their own drive without proper Drive API setup."
                 )
-            
+
             google_sheets_url = new_spreadsheet.url
             spreadsheet_id = new_spreadsheet.id
         else:
@@ -545,8 +673,6 @@ def convert_excel_to_google_sheets_bulk(
                         excel_data[sheet_name] = sheet_data.values
                         converted_sheets.append(sheet_name)
                 except Exception as e:
-                    import logging
-
                     logging.warning(f"Failed to read sheet '{sheet_name}': {e}")
 
         if not excel_data:
@@ -596,8 +722,6 @@ def convert_excel_to_google_sheets_bulk(
                 for response in result.get("responses", [])
             )
 
-            import logging
-
             logging.info(
                 f"Bulk update completed: {total_updated_cells} cells updated in single API call"
             )
@@ -616,21 +740,17 @@ def convert_excel_to_google_sheets_bulk(
                             and len(final_metadata.sheet_names) > 1
                         ):
                             target_spreadsheet.delete_sheet(default_name)
-                            import logging
-
                             logging.info(
                                 f"Removed unused default sheet: {default_name}"
                             )
             except Exception as e:
-                import logging
-
                 logging.warning(f"Could not remove default sheet: {e}")
 
         result = {"success": True, "converted_sheets": converted_sheets, "error": None}
-        
+
         # Include the Google Sheets URL (especially important for auto-created sheets)
         result["output_url"] = google_sheets_url
-        
+
         return result
 
     except Exception as e:
@@ -774,8 +894,6 @@ def convert_spreadsheet_format(
                     target_file_type=target_file_type,
                 )
             except ImportError:
-                import logging
-
                 logging.warning(
                     "Enhanced formatting not available - falling back to basic conversion"
                 )
@@ -941,8 +1059,6 @@ def _copy_google_sheets_to_google_sheets(
                         converted_sheets.append(sheet_name)
 
                     except Exception as e:
-                        import logging
-
                         logging.warning(f"Failed to copy sheet '{sheet_name}': {e}")
 
         return {"success": True, "converted_sheets": converted_sheets, "error": None}
@@ -994,8 +1110,6 @@ def _copy_excel_to_excel(
                         converted_sheets.append(sheet_name)
 
                     except Exception as e:
-                        import logging
-
                         logging.warning(f"Failed to copy sheet '{sheet_name}': {e}")
 
                 # Remove default sheet AFTER adding all copied sheets
@@ -1009,12 +1123,8 @@ def _copy_excel_to_excel(
                                 and len(target_metadata.sheet_names) > 1
                             ):
                                 target_spreadsheet.delete_sheet(default_name)
-                                import logging
-
                                 logging.info(f"Removed default sheet: {default_name}")
                     except Exception as e:
-                        import logging
-
                         logging.warning(f"Could not remove default sheet: {e}")
 
                 target_spreadsheet.save()
@@ -1033,3 +1143,85 @@ def _copy_excel_to_excel(
             "output_path": None,
             "error": str(e),
         }
+
+
+def _generate_unique_filename(file_path: Path) -> Path:
+    """Generate a unique filename by adding (1), (2), etc. if the file already exists.
+
+    Args:
+        file_path: The original file path
+
+    Returns:
+        A unique file path that doesn't exist
+    """
+
+    # Extract stem and extension
+    stem = file_path.stem
+    suffix = file_path.suffix
+    parent = file_path.parent
+
+    # Check if any files with similar names already exist
+    # Look for files that start with the same stem and have optional (n) suffix
+    existing_files = []
+    for existing_file in parent.glob(f"{stem}*{suffix}"):
+        if existing_file != file_path:  # Don't include the target file itself
+            existing_files.append(existing_file)
+
+    # Also check for files that match the exact stem pattern
+    exact_matches = []
+    for existing_file in existing_files:
+        existing_stem = existing_file.stem
+        # Check if this is the base name or a numbered version
+        if existing_stem == stem:
+            exact_matches.append(existing_file)
+        elif re.match(rf"^{re.escape(stem)}\s*\(\d+\)\s*$", existing_stem):
+            exact_matches.append(existing_file)
+
+    # If no exact matches found with glob, try a more comprehensive search
+    if not exact_matches:
+        # Look for any files that might be related to this stem
+        for existing_file in parent.iterdir():
+            if existing_file.is_file() and existing_file.suffix == suffix:
+                existing_stem = existing_file.stem
+                # Check if this is the base name or a numbered version
+                if existing_stem == stem:
+                    exact_matches.append(existing_file)
+                elif re.match(rf"^{re.escape(stem)}\s*\(\d+\)\s*$", existing_stem):
+                    exact_matches.append(existing_file)
+
+    if not exact_matches:
+        # No similar files exist, return the original path
+        return file_path
+
+    # Check if stem already ends with (n)
+    # Use a more robust regex that handles spaces and parentheses correctly
+    match = re.match(r"^(.+?)\s*\((\d+)\)\s*$", stem)
+    if match:
+        base_stem = match.group(1).rstrip()  # Remove trailing spaces
+        current_num = int(match.group(2))
+        next_num = current_num + 1
+    else:
+        base_stem = stem
+        next_num = 1
+
+    # Find the highest existing number to determine the next number
+    highest_existing_num = 0
+    for existing_file in exact_matches:
+        existing_stem = existing_file.stem
+        match = re.match(rf"^{re.escape(base_stem)}\s*\((\d+)\)\s*$", existing_stem)
+        if match:
+            num = int(match.group(1))
+            if num > highest_existing_num:
+                highest_existing_num = num
+
+    # Start from the next number after the highest existing
+    if highest_existing_num > 0:
+        next_num = highest_existing_num + 1
+
+    # Find the next available number
+    while True:
+        new_stem = f"{base_stem} ({next_num})"
+        new_path = parent / f"{new_stem}{suffix}"
+        if not new_path.exists():
+            return new_path
+        next_num += 1
